isHidden property
bool
get
isHidden
Returns true if the annotated field should be hidden from JSON.
Implementation
bool get isHidden => _hidden;
Returns true if the annotated field should be hidden from JSON.
bool get isHidden => _hidden;